==> haskell-typed-process-0.2.13.0-150-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-typed-process.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 typed-process
version:              0.2.13.0
visibility:           public
id:                   typed-process-0.2.13.0-86eXAknEMBO1d8XgisaSB2
key:                  typed-process-0.2.13.0-86eXAknEMBO1d8XgisaSB2
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/typed-process
synopsis:             Run external processes, with strong typing of streams
description:
    Please see the tutorial at <https://github.com/fpco/typed-process#readme>

category:             System
abi:                  8731f4c87489643c91043e694baf084d
exposed:              True
exposed-modules:      System.Process.Typed System.Process.Typed.Internal
hidden-modules:       Paths_typed_process
import-dirs:          /usr/lib/ghc-9.6.6/site-local/typed-process-0.2.13.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/typed-process-0.2.13.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/typed-process-0.2.13.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-typed-process
hs-libraries:         HStyped-process-0.2.13.0-86eXAknEMBO1d8XgisaSB2
depends:
    async-2.2.5-FvjGBjK4DRS7J0bkB6uzOe base-4.18.2.1
    bytestring-0.11.5.3 process-1.6.19.0 stm-2.5.1.0 text-2.0.2
    transformers-0.6.1.0 unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:
    /usr/share/doc/haskell-typed-process/html/typed-process.haddock

haddock-html:         /usr/share/doc/haskell-typed-process/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-typed-process-0.2.13.0-151-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-typed-process.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 typed-process
version:              0.2.13.0
visibility:           public
id:                   typed-process-0.2.13.0-EPUkCrQoI0W1g2Dd9OPs5
key:                  typed-process-0.2.13.0-EPUkCrQoI0W1g2Dd9OPs5
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/typed-process
synopsis:             Run external processes, with strong typing of streams
description:
    Please see the tutorial at <https://github.com/fpco/typed-process#readme>

category:             System
abi:                  9ccdad7a1b285f0289c59aaaa92a1799
exposed:              True
exposed-modules:      System.Process.Typed System.Process.Typed.Internal
hidden-modules:       Paths_typed_process
import-dirs:          /usr/lib/ghc-9.6.6/site-local/typed-process-0.2.13.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/typed-process-0.2.13.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/typed-process-0.2.13.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-typed-process
hs-libraries:         HStyped-process-0.2.13.0-EPUkCrQoI0W1g2Dd9OPs5
depends:
    async-2.2.5-A7cw4gHfrNnBMjsgvHD8kq base-4.18.2.1
    bytestring-0.11.5.3 process-1.6.19.0 stm-2.5.1.0 text-2.0.2
    transformers-0.6.1.0 unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:
    /usr/share/doc/haskell-typed-process/html/typed-process.haddock

haddock-html:         /usr/share/doc/haskell-typed-process/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
